# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Drop Python 2 bindings from Fedora 31, RHEL-8 onwards (#1738016)
%if 0%{?fedora} < 31 && 0%{?rhel} < 8
%global with_python2 1
%else
%global with_python2 0
%endif

# Python bindings only ported to Python 3 from 1.1.36
# Fedora built them from Fedora 37 onwards
%if 0%{?fedora} < 37 && 0%{?rhel} < 10
%global with_python3 0
%else
%global with_python3 1
%endif

Summary:	Library providing the Gnome XSLT engine
Name:		libxslt
Version:	1.1.42
Release:	1.0.cf.%{__distinit}%{__distvers}
License:	MIT
URL:		https://gitlab.gnome.org/GNOME/libxslt
Source0:	https://download.gnome.org/sources/libxslt/1.1/libxslt-%{version}.tar.xz
Patch0:		multilib.patch
Patch1:		multilib2.patch
Patch10:	libxslt-1.1.38-utf8.patch
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	hardlink
BuildRequires:	make
BuildRequires:	libxml2-devel >= 2.6.27
Requires:	libxml2%{?_isa} >= 2.6.27
Provides:	xsltproc = %{version}-%{release}

# Filter provide for python binding shared object
%global __provides_exclude ^libxsltmod.so(\\(\\)\\(64bit\\))?$

%description
This C library allows to transform XML files into other XML files (or HTML,
text, ...) using the standard XSLT stylesheet transformation mechanism. The
xsltproc command is a command line interface to the XSLT engine

%package devel
Summary:	Libraries, includes, etc. to embed the Gnome XSLT engine
Requires:	libxslt%{?_isa} = %{version}-%{release}
Requires:	libxml2-devel%{?_isa} >= 2.6.27

%description devel
The libxslt-devel package contains libraries and header files for developing
applications that use libxslt.

%if %{with_python2}
%package -n python2-libxslt
Summary:	Python 2 bindings for the libxslt library
BuildRequires:	python2-devel >= 2.4
BuildRequires:	python2-libxml2
Requires:	libxslt%{?_isa} = %{version}-%{release}
Requires:	python2-libxml2%{?_isa} >= 2.6.27
Provides:	libxslt-python = %{version}-%{release}
Obsoletes:	libxslt-python < %{version}-%{release}
Provides:	libxslt-python%{?_isa} = %{version}-%{release}
Provides:	python-libxslt = %{version}-%{release}
Provides:	python-libxslt%{?_isa} = %{version}-%{release}

%description -n python2-libxslt
The python2-libxslt package contains a module that permits applications written
in the Python 2 programming language to use the interface supplied by the
libxslt library to apply XSLT transformations.

This library allows to parse stylesheets, and uses python2-libxml2 to load and
save XML and HTML files. Direct access to XPath and the XSLT transformation
context are possible to extend the XSLT language with XPath functions written
in Python 2.
%endif

%if %{with_python3}
%package -n python3-libxslt
Summary:	Python 3 bindings for the libxslt library
BuildRequires:	python3-devel
BuildRequires:	python3-libxml2
Requires:	libxslt%{?_isa} = %{version}-%{release}
Requires:	python3-libxml2%{?_isa} >= 2.6.27
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-libxslt
The python3-libxslt package contains a module that permits applications written
in the Python 3 programming language to use the interface supplied by the
libxslt library to apply XSLT transformations.

This library allows to parse stylesheets, and uses python3-libxml2 to load and
save XML and HTML files. Direct access to XPath and the XSLT transformation
context are possible to extend the XSLT language with XPath functions written
in Python 3.
%endif

%prep
%setup -q

# Fix multilib issues
%patch -P 0 -p1
%patch -P 1 -p1

# Re-code NEWS as UTF8
%patch -P 10

# Exec permissions not needed on python scripts
chmod -c -x python/tests/*.py

%build
# We never build both Python 2 and Python 3 bindings
%if %{with_python2}
export PYTHON=%{__python2}
%endif
%if %{with_python3}
export PYTHON=%{__python3}
%endif
%if %{with_python2} || %{with_python3}
%configure --disable-static --disable-silent-rules --with-python
%else
%configure --disable-static --disable-silent-rules --with-python=no
%endif
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} INSTALL="install -p" install

# Remove files we don't want packaged
find %{buildroot} -name '*.la' -print -delete
# rpm 4.9 doesn't remove docs automatically, and we're specifying these manually
rm -vrf %{buildroot}%{_docdir}

# Multiarch crazyness on timestamp differences
touch -m --reference=%{buildroot}%{_includedir}/libxslt/xslt.h \
	%{buildroot}%{_bindir}/xslt-config

# hardlink identical images and stylesheets together
hardlink -cv %{buildroot}%{_datadir}/gtk-doc/html

%check
make tests

%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
# ldconfig scriptlets replaced by RPM File Triggers from Fedora 28
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%files
%license Copyright
%doc AUTHORS NEWS README.md FEATURES
%{_bindir}/xsltproc
%{_libdir}/libexslt.so.*
%{_libdir}/libxslt.so.*
%{_libdir}/libxslt-plugins
%{_mandir}/man1/xsltproc.1*

%files devel
%doc doc/tutorial/ doc/tutorial2/
%doc doc/libxslt-api.xml
%{_bindir}/xslt-config
%{_datadir}/gtk-doc/
%{_includedir}/libexslt/
%{_includedir}/libxslt/
%{_libdir}/cmake/libxslt/
%{_libdir}/libexslt.so
%{_libdir}/libxslt.so
%{_libdir}/xsltConf.sh
%{_libdir}/pkgconfig/libxslt.pc
%{_libdir}/pkgconfig/libexslt.pc
%{_mandir}/man3/libxslt.3*
%{_mandir}/man3/libexslt.3*

%if %{with_python2}
%files -n python2-libxslt
%doc python/libxsltclass.txt
%doc python/tests/*.py
%doc python/tests/*.xml
%doc python/tests/*.xsl
%{python2_sitelib}/libxslt.py*
%{python2_sitearch}/libxsltmod.so
%endif

%if %{with_python3}
%files -n python3-libxslt
%doc python/libxsltclass.txt
%doc python/tests/*.py
%doc python/tests/*.xml
%doc python/tests/*.xsl
%{python3_sitearch}/libxsltmod.so
%{python3_sitelib}/libxslt.py*
%{python3_sitelib}/__pycache__/libxslt*
%endif

%changelog
* Sun Jul  7 2024 Paul Howarth <paul@city-fan.org> - 1.1.42-1.0.cf
- Update to 1.1.42
  Regressions:
  - extensions: Re-add call to xmlCheckFilename with older libxml2
  Improvements:
  - utils: Don't use deprecated xmlCharEncodingHandler member
  - transform: Handle filesystem paths after libxml2 changes
  - locale: Work around issue with FreeBSD's strxfrm_l
  Build Systems:
  - cmake: Add LIBXSLT_WITH_PROGRAMS option
  - cmake: Fix HAVE_GCRYPT check

* Wed Jun 26 2024 Paul Howarth <paul@city-fan.org> - 1.1.41-2.0.cf
- extensions: re-add call to xmlCheckFilename with older libxml2 (GL#113)

* Thu Jun 20 2024 Paul Howarth <paul@city-fan.org> - 1.1.41-1.0.cf
- Update to 1.1.41
  Removals:
  - autotools: Stop installing libxslt.m4
  - autotools: Remove RPM build
  Improvements:
  - libxslt: Set _FILE_OFFSET_BITS to 64
  - xsltproc: Remove unneeded includes
  - include: Don't define ATTRIBUTE_UNUSED in public header
  - xsltproc: Make "-" read from stdin
  Build Systems:
  - cmake: Adjust paths for UNIX or UNIX-like target systems
  Tests:
  - cmake: Link testplugin with libxml2
  - tests: Link testplugin with libxml2
  - tests: Fix expected error after libxml2 change
  - runtest: Switch to xmlFormatError
  - fuzz: Avoid accessing internal struct members

* Thu Jun 13 2024 Paul Howarth <paul@city-fan.org> - 1.1.40-1.0.cf
- Update to 1.1.40
  Removals:
  - xsltproc: Remove maxparserdepth option
  Improvements:
  - functions: xmlXPtrNewContext is deprecated
  - xsltproc: Stop calling xmlMemoryDump
  - xsltproc: Prefer XML_PARSE_NONET over xmlNoNetEntityLoader
  - functions: Fix build if libxml2 modules are disabled
  - extensions: Don't call deprecated xmlCheckFilename
  - documents: Don't set ctxt->directory
  - exslt: Fix EXSLT functions without parameters
  Build Systems:
  - build: Remove mem-debug option
- Hardlink identical packaged files together to save space

* Thu Jan 25 2024 Paul Howarth <paul@city-fan.org> - 1.1.39-3.0.cf
- Re-rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild
  (see https://pagure.io/releng/issue/11888)

* Mon Jan 22 2024 Paul Howarth <paul@city-fan.org> - 1.1.39-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Nov 20 2023 Paul Howarth <paul@city-fan.org> - 1.1.39-1.0.cf
- Update to 1.1.39 (see NEWS for details)

* Thu Jul 20 2023 Paul Howarth <paul@city-fan.org> - 1.1.38-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Wed Jul  5 2023 Paul Howarth <paul@city-fan.org> - 1.1.38-2.0.cf
- Rebuilt for Python 3.12

* Tue May  9 2023 Paul Howarth <paul@city-fan.org> - 1.1.38-1.0.cf
- Update to 1.1.38 (see NEWS for details)
- Avoid use of deprecated patch syntax
- Add patch to convert NEWS to UTF8 encoding

* Sun Mar  5 2023 Paul Howarth <paul@city-fan.org> - 1.1.37-3.0.cf
- Migrated to SPDX license

* Fri Jan 20 2023 Paul Howarth <paul@city-fan.org> - 1.1.37-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Tue Aug 30 2022 Paul Howarth <paul@city-fan.org> - 1.1.37-1.0.cf
- Update to 1.1.37
  - Don't use deprecated libxml2 macros
  - Don't mess with xmlDefaultSAXHandler
  - Require automake-1.16.3 or later
  - Remove generated files from distribution
  - Add missing compile definition for static builds to Autotools

* Mon Aug 22 2022 Paul Howarth <paul@city-fan.org> - 1.1.36-1.0.cf
- Update to 1.1.36 (see NEWS for details)
- Package Python 3 bindings from Fedora 37 onwards

* Sun Jul 24 2022 Paul Howarth <paul@city-fan.org> - 1.1.35-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Fri Jun 17 2022 Paul Howarth <paul@city-fan.org> - 1.1.35-2.0.cf
- Rebuild to sync with Rawhide

* Thu Feb 17 2022 Paul Howarth <paul@city-fan.org> - 1.1.35-1.0.cf
- Update to 1.1.35 (see NEWS for details)
  - Includes fix for CVE-2021-30560: use-after-free in xsltApplyTemplates
- Switch upstream from xmlsoft.org to gnome.org
- Add provide for xsltproc

* Sun Feb  6 2022 Paul Howarth <paul@city-fan.org> - 1.1.34-9.0.cf
- Fix build of tests/fuzz (#2047653)
- Fix DTD in tutorial XML (#2047326)
- Fix validity of tutorial XML (#2047326)

* Sun Jan 23 2022 Paul Howarth <paul@city-fan.org> - 1.1.34-7.1.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sun Dec 12 2021 Paul Howarth <paul@city-fan.org> - 1.1.34-7.0.cf
- Fix dist tags for CentOS Stream

* Fri Jul 23 2021 Paul Howarth <paul@city-fan.org> - 1.1.34-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild
- Fix dist tags for Alma and Rocky Linux

* Thu Jan 28 2021 Paul Howarth <paul@city-fan.org> - 1.1.34-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Sep 23 2020 Paul Howarth <paul@city-fan.org> - 1.1.34-4.0.cf
- Fix for incorrect man page stylesheet
  https://gitlab.gnome.org/GNOME/libxslt/-/issues/31

* Fri Sep  4 2020 Paul Howarth <paul@city-fan.org> - 1.1.34-3.0.cf
- Drop crypto dependencies; the "cryptography" implemented in xslt is outdated
  and bad, supporting only insecure algorithms (RC4, SHA1, MD5, MD4), and
  should not be used anyway

* Wed Jul 29 2020 Paul Howarth <paul@city-fan.org> - 1.1.34-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Mar 10 2020 Paul Howarth <paul@city-fan.org> - 1.1.34-1.0.cf
- Update to 1.1.34

* Fri Jan 31 2020 Paul Howarth <paul@city-fan.org> - 1.1.33-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Oct 31 2019 Paul Howarth <paul@city-fan.org> - 1.1.33-4.1.cf
- Drop python bindings for RHEL-8 builds too

* Sun Oct 13 2019 Paul Howarth <paul@city-fan.org> - 1.1.33-4.0.cf
- Do not build python bindings even if the python is available
- Fix CVE-2019-13117 (#1728547)
- Fix CVE-2019-13118 (#1728542)

* Wed Sep 11 2019 Paul Howarth <paul@city-fan.org> - 1.1.33-3.0.cf
- Drop Python 2 bindings from Fedora 31 onwards (#1738016)

* Mon Aug 12 2019 Paul Howarth <paul@city-fan.org> - 1.1.33-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Jun 10 2019 Paul Howarth <paul@city-fan.org> - 1.1.33-1.0.cf
- Update to 1.1.33
- Fix CVE-2019-11068 (#1709698)

* Mon Jun  3 2019 Paul Howarth <paul@city-fan.org> - 1.1.32-5.0.cf
- Apply an extra patch to make it possible to co-install libxslt-devel.x86_64
  and libxslt-devel.i686 (#1467435)

* Tue Feb  5 2019 Paul Howarth <paul@city-fan.org> - 1.1.32-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Jul 17 2018 Paul Howarth <paul@city-fan.org> - 1.1.32-3.0.cf
- Explicitly use Python 2 for python bindings

* Mon Feb 19 2018 Paul Howarth <paul@city-fan.org> - 1.1.32-2.0.cf
- Update to 1.1.32 (mainly portability fixes)
- Drop %%{?_isa} from build requirements
- Re-enable hardened build

* Fri Feb  9 2018 Paul Howarth <paul@city-fan.org> - 1.1.30-5.0.cf
- ldconfig scriptlets replaced by RPM File Triggers from Fedora 28
- Use forward-looking conditionals

* Mon Oct  9 2017 Paul Howarth <paul@city-fan.org> - 1.1.30-2.0.cf
- Fix broken xslt-config binary (#1498539)

* Thu Sep  7 2017 Paul Howarth <paul@city-fan.org> - 1.1.30-1.0.cf
- Update to 1.1.30 (lots of bug fixes and enhancements; see
  http://xmlsoft.org/XSLT/news.html for details)
- Make dependencies arch-specific

* Wed Aug 23 2017 Paul Howarth <paul@city-fan.org> - 1.1.29-6.0.cf
- Python 2 binary package renamed to python2-libxslt
  (see https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Fri Aug  4 2017 Paul Howarth <paul@city-fan.org> - 1.1.29-4.0.cf
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - %%{python_sitearch} is always defined
  - pkgconfig dependency for devel package is always auto-detected

* Thu Nov 10 2016 Paul Howarth <paul@city-fan.org> - 1.1.29-2.0.cf
- Fix heap overread in xsltFormatNumberConversion (CVE-2016-4738)

* Tue May 24 2016 Paul Howarth <paul@city-fan.org> - 1.1.29-1.0.cf
- Update to 1.1.29
  - CVE-2015-7995: Fix for type confusion in preprocessing attributes
  - Various other bug and portability fixes: see NEWS for details
- Update UTF8 patch
- Define macros in global scope

* Thu Feb  4 2016 Paul Howarth <paul@city-fan.org> - 1.1.28-12.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Jun 21 2015 Paul Howarth <paul@city-fan.org> - 1.1.28-11.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Mar  9 2015 Paul Howarth <paul@city-fan.org> - 1.1.28-10.0.cf
- De-activate the hardened build as it seems buggy (#1199522)

* Sun Feb 22 2015 Paul Howarth <paul@city-fan.org> - 1.1.28-9.0.cf
- Rebuilt for Fedora 23 Change
  https://fedoraproject.org/wiki/Changes/Harden_all_packages_with_position-independent_code

* Tue Aug 19 2014 Paul Howarth <paul@city-fan.org> - 1.1.28-8.0.cf
- Use %%license where possible

* Wed Jun 11 2014 Paul Howarth <paul@city-fan.org> - 1.1.28-7.0.cf
- Drop %%defattr, redundant since rpm 4.4
- Drop python 2.3 support, not needed from FC-5 onwards

* Mon Mar  3 2014 Paul Howarth <paul@city-fan.org> - 1.1.28-6.0.cf
- Rebuild for libgcrypt 1.6.x in Rawhide

* Tue Aug  6 2013 Paul Howarth <paul@city-fan.org> - 1.1.28-5.0.cf
- Avoid duplicate packaging of python examples

* Sun Aug  4 2013 Paul Howarth <paul@city-fan.org> - 1.1.28-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jun 23 2013 Paul Howarth <paul@city-fan.org> - 1.1.28-3.0.cf
- Lots of API docs were in the main package rather than the devel package

* Sat Feb 23 2013 Paul Howarth <paul@city-fan.org> - 1.1.28-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Nov 22 2012 Paul Howarth <paul@city-fan.org> - 1.1.28-1.0.cf
- Update to 1.1.28
  Portability:
  - Fix python build by using libxsltmod_la_CPPFLAGS instead of AM_CPPFLAGS
  - configure should be more careful with linker script
  - Add gcrypt library in LIBADD, not LDFLAGS, as recommended
  Bug fixes:
  - Fix generate-id() to avoid generating the same ID
  - Fix crash with empty xsl:key/@match attribute
  - Fix crash when passing an uninitialized variable to document()
  - Add missing test docs to EXTRA_DIST
  - Fix regression: Default namespace not correctly used
  Cleanups:
  - Remove xsltTransStorageAdd and xsltTransStorageRemove from symbols.xml
  - autogen.sh cleanup
  - Consistent use of xslt processor
  - Add object files in tests/plugins to .gitignore
  - Fix error on bug-165 regression test
  - Remove xsltTransStorageAdd and xsltTransStorageRemove
- Drop patch for Gnome Bug #684564, now in upstream release
- Do build in verbose mode so we can see the compiler flags

* Wed Oct 10 2012 Paul Howarth <paul@city-fan.org> - 1.1.27-2.0.cf
- Fix a regression in default namespace handling (Gnome Bug #684564)

* Wed Sep 12 2012 Paul Howarth <paul@city-fan.org> - 1.1.27-1.0.cf
- Update to 1.1.27 (lots of bug-fixes and improvements)
- Update UTF8 patch

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 1.1.26-10.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Aug  6 2011 Paul Howarth <paul@city-fan.org> - 1.1.26-9.0.cf
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux
- Don't package python binding's empty TODO file
- Remove doubly-packaged python docs with rpm 4.9

* Mon Mar 21 2011 Paul Howarth <paul@city-fan.org> - 1.1.26-8.0.cf
- ChangeLog: fix character encoding
- Restore timestamps for patched documentation files
- Filter provide for python binding shared object (rpm 4.9 onwards)

* Tue Feb  8 2011 Paul Howarth <paul@city-fan.org> - 1.1.26-7.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Dec 19 2010 Paul Howarth <paul@city-fan.org> - 1.1.26-6.0.cf
- Resync with Rawhide again

* Thu Oct 28 2010 Paul Howarth <paul@city-fan.org> - 1.1.26-5.0.cf
- Renumber patches to match Rawhide build

* Fri Oct 22 2010 Paul Howarth <paul@city-fan.org> - 1.1.26-4.0.cf
- Drop redundant dependencies
- Maintain timestamps where possible

* Wed Jul 28 2010 Paul Howarth <paul@city-fan.org> - 1.1.26-3.1.cf
- Rebuild for python 2.7 in Rawhide

* Tue May 25 2010 Paul Howarth <paul@city-fan.org> - 1.1.26-3.0.cf
- Drop %%{_datadir}/aclocal dependency from devel package from Fedora 14,
  where this directory is part of the filesystem package (#533962)
- Drop manual pkgconfig dependency from devel package from Fedora 11, where
  this dependency is auto-detected
- Fix dist tag for RHEL-6 Beta

* Thu Feb 25 2010 Paul Howarth <paul@city-fan.org> - 1.1.26-2.0.cf
- Dist tag for Rawhide no longer needs special-casing

* Fri Sep 25 2009 Paul Howarth <paul@city-fan.org> - 1.1.26-1.0.cf
- Release of 1.1.26 (see NEWS for details)
- Patch for locking bug upstreamed
- Run the test suite in %%check

* Mon Sep 21 2009 Paul Howarth <paul@city-fan.org> - 1.1.25-2.0.cf
- Fix a locking bug in 1.1.25
- Include extra docs, drop empty python TODO

* Thu Sep 17 2009 Daniel Veillard <veillard@redhat.com> - 1.1.25-1
- Release of 1.1.25
  - add API versioning for libxslt shared library
  - xsl:sort lang support using the locale
  - many bug fixes

* Tue Mar  3 2009 Paul Howarth <paul@city-fan.org> - 1.1.24-4.0.cf
- Import from Fedora
- Don't build static libraries
- Clean up spec
- Recode ChangeLog and NEWS as UTF-8

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.24-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 1.1.24-3
- Rebuild for Python 2.6

* Wed Oct  8 2008 Daniel Veillard <veillard@redhat.com> - 1.1.24-2.fc10
- CVE-2008-2935 fix

* Tue May 13 2008 Daniel Veillard <veillard@redhat.com> - 1.1.24-1.fc10
- release of 1.1.24
- fixes a few bugs including the key initialization problem
- tentative fix for multiarch devel problems

* Mon Apr 28 2008 Daniel Veillard <veillard@redhat.com> - 1.1.23-3.fc10
- and the previous patch was incomplete breaking the python bindings
  see 444317 and 444455

* Tue Apr 22 2008 Daniel Veillard <veillard@redhat.com> - 1.1.23-2.fc10
- revert a key initialization patch from 1.1.23 which seems broken
  see rhbz#442097

* Tue Apr  8 2008 Daniel Veillard <veillard@redhat.com> - 1.1.23-1.fc9
- upstream release 1.1.23
- bugfixes

* Wed Feb 20 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.1.22-2
- Autorebuild for GCC 4.3

* Thu Aug 23 2007 Daniel Veillard <veillard@redhat.com> - 1.1.22-1
- upstream release 1.1.22 see http://xmlsoft.org/XSLT/news.html

* Tue Jun 12 2007 Daniel Veillard <veillard@redhat.com> - 1.1.21-1
- upstream release 1.1.21 see http://xmlsoft.org/XSLT/news.html

* Thu Feb 15 2007 Adam Jackson <ajax@redhat.com>
- Add dist tag to Release to fix 6->7 upgrades

* Wed Jan 17 2007 Daniel Veillard <veillard@redhat.com>
- upstream release 1.1.20 see http://xmlsoft.org/XSLT/news.html

* Thu Dec  7 2006 Jeremy Katz <katzj@redhat.com> - 1.1.19-2
- rebuild against python 2.5

* Wed Nov 29 2006 Daniel Veillard <veillard@redhat.com>
- upstream release 1.1.19 see http://xmlsoft.org/XSLT/news.html

* Thu Oct 26 2006 Daniel Veillard <veillard@redhat.com>
- upstream release 1.1.18 see http://xmlsoft.org/XSLT/news.html

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.1.17-1.1
- rebuild

* Tue Jun  6 2006 Daniel Veillard <veillard@redhat.com>
- upstream release 1.1.17 see http://xmlsoft.org/XSLT/news.html
